@@ -1,4 +1,5 @@
 # requirements
+import pkg_resources
 
 def additional_tests():
     import doctest
@@ -16,8 +17,9 @@ def additional_tests():
 
 
 def _checkSample(testcase, installed):
+    version = pkg_resources.require('pkginfo')[0].version
     testcase.assertEqual(installed.name, 'pkginfo')
-    testcase.assertEqual(installed.version, '0.4.1')
+    testcase.assertEqual(installed.version, version)
     testcase.assertEqual(installed.keywords,
                         'distribution sdist installed metadata' )
     testcase.assertEqual(list(installed.supported_platforms), [])
