@@ -38,6 +38,7 @@ class DistributionTests(unittest.TestCase):
         self.assertEqual(sdist.requires_dist, ())
         self.assertEqual(sdist.provides_dist, ())
         self.assertEqual(sdist.obsoletes_dist, ())
+        self.assertEqual(sdist.project_urls, ())
 
     def test_parse_Metadata_Version_1_0(self):
         from pkginfo.distribution import HEADER_ATTRS_1_0
@@ -96,12 +97,28 @@ class DistributionTests(unittest.TestCase):
         self.assertEqual(dist.summary, 'Package for foo')
 
     def test_parse_Description(self):
+        dist = self._makeOne()
+        dist.parse('Description: This package enables integration with '
+                   'foo servers.')
+        self.assertEqual(dist.description,
+                         'This package enables integration with '
+                         'foo servers.')
+
+    def test_parse_Description_multiline(self):
+        dist = self._makeOne()
+        dist.parse('Description: This package enables integration with\n'
+                   ' foo servers.')
+        self.assertEqual(dist.description,
+                         'This package enables integration with '
+                         'foo servers.')
+
+    def test_parse_Description_multiline_extra_leading_ws(self):
         dist = self._makeOne()
         dist.parse('Description: This package enables integration with\n'
                    '       foo servers.')
         self.assertEqual(dist.description,
-                         'This package enables integration with\n'
-                         ' foo servers.')
+                         'This package enables integration with '
+                         'foo servers.')
 
     def test_parse_Keywords(self):
         dist = self._makeOne()
@@ -246,62 +263,101 @@ class DistributionTests(unittest.TestCase):
                          ])
 
 
-    def test_parse_Requires_single_wo_version(self):
+    def test_parse_Requires_Dist_single_wo_version(self):
         dist = self._makeOne('1.2')
         dist.parse('Requires-Dist: SpanishInquisition')
         self.assertEqual(list(dist.requires_dist), ['SpanishInquisition'])
 
-    def test_parse_Requires_single_w_version(self):
+    def test_parse_Requires_Dist_single_w_version(self):
         dist = self._makeOne('1.2')
         dist.parse('Requires-Dist: SpanishInquisition (>=1.3)')
         self.assertEqual(list(dist.requires_dist),
                          ['SpanishInquisition (>=1.3)'])
 
-    def test_parse_Requires_multiple(self):
+    def test_parse_Requires_Dist_single_w_env_marker(self):
         dist = self._makeOne('1.2')
-        dist.parse('Requires-Dist: SpanishInquisition\n'
-                   'Requires-Dist: SillyWalks (1.4)\n'
-                   'Requires-Dist: kniggits (>=2.3,<3.0)')
+        dist.parse("Requires-Dist: SpanishInquisition; "
+                        "python_version == '1.4'")
         self.assertEqual(list(dist.requires_dist),
-                         ['SpanishInquisition',
-                          'SillyWalks (1.4)',
-                          'kniggits (>=2.3,<3.0)',
+                         ["SpanishInquisition; python_version == '1.4'"])
+
+    def test_parse_Requires_Dist_multiple(self):
+        dist = self._makeOne('1.2')
+        dist.parse("Requires-Dist: SpanishInquisition\n"
+                   "Requires-Dist: SillyWalks; python_version == '1.4'\n"
+                   "Requires-Dist: kniggits (>=2.3,<3.0)")
+        self.assertEqual(list(dist.requires_dist),
+                         ["SpanishInquisition",
+                          "SillyWalks; python_version == '1.4'",
+                          "kniggits (>=2.3,<3.0)",
                          ])
 
-    def test_parse_Provides_single_wo_version(self):
+    def test_parse_Provides_Dist_single_wo_version(self):
         dist = self._makeOne('1.2')
         dist.parse('Provides-Dist: SillyWalks')
         self.assertEqual(list(dist.provides_dist), ['SillyWalks'])
 
-    def test_parse_Provides_single_w_version(self):
+    def test_parse_Provides_Dist_single_w_version(self):
         dist = self._makeOne('1.2')
         dist.parse('Provides-Dist: SillyWalks (1.4)')
         self.assertEqual(list(dist.provides_dist), ['SillyWalks (1.4)'])
 
-    def test_parse_Provides_multiple(self):
+    def test_parse_Provides_Dist_single_w_env_marker(self):
         dist = self._makeOne('1.2')
-        dist.parse('Provides-Dist: SillyWalks\n'
-                   'Provides-Dist: DeadlyJoke (3.1.4)')
+        dist.parse("Provides-Dist: SillyWalks; sys.platform == 'os2'")
         self.assertEqual(list(dist.provides_dist),
-                         ['SillyWalks',
-                          'DeadlyJoke (3.1.4)',
+                         ["SillyWalks; sys.platform == 'os2'"])
+
+    def test_parse_Provides_Dist_multiple(self):
+        dist = self._makeOne('1.2')
+        dist.parse("Provides-Dist: SillyWalks\n"
+                   "Provides-Dist: SpanishInquisition; sys.platform == 'os2'\n"
+                   "Provides-Dist: DeadlyJoke (3.1.4)")
+        self.assertEqual(list(dist.provides_dist),
+                         ["SillyWalks",
+                          "SpanishInquisition; sys.platform == 'os2'",
+                          "DeadlyJoke (3.1.4)",
                          ])
 
-    def test_parse_Obsoletes_single_no_version(self):
+    def test_parse_Obsoletes_Dist_single_no_version(self):
         dist = self._makeOne('1.2')
         dist.parse('Obsoletes-Dist: SillyWalks')
         self.assertEqual(list(dist.obsoletes_dist), ['SillyWalks'])
 
-    def test_parse_Obsoletes_single_w_version(self):
+    def test_parse_Obsoletes_Dist_single_w_version(self):
         dist = self._makeOne('1.2')
         dist.parse('Obsoletes-Dist: SillyWalks (<=1.3)')
         self.assertEqual(list(dist.obsoletes_dist), ['SillyWalks (<=1.3)'])
 
-    def test_parse_Obsoletes_multiple(self):
+    def test_parse_Obsoletes_Dist_single_w_env_marker(self):
         dist = self._makeOne('1.2')
-        dist.parse('Obsoletes-Dist: kniggits\n'
-                   'Obsoletes-Dist: SillyWalks (<=2.0)')
+        dist.parse("Obsoletes-Dist: SillyWalks; sys.platform == 'os2'")
         self.assertEqual(list(dist.obsoletes_dist),
-                         ['kniggits',
-                          'SillyWalks (<=2.0)',
+                         ["SillyWalks; sys.platform == 'os2'"])
+
+    def test_parse_Obsoletes_Dist_multiple(self):
+        dist = self._makeOne('1.2')
+        dist.parse("Obsoletes-Dist: kniggits\n"
+                   "Obsoletes-Dist: SillyWalks; sys.platform == 'os2'\n"
+                   "Obsoletes-Dist: DeadlyJoke (<=2.0)\n"
+                  )
+        self.assertEqual(list(dist.obsoletes_dist),
+                         ["kniggits",
+                          "SillyWalks; sys.platform == 'os2'",
+                          "DeadlyJoke (<=2.0)",
+                         ])
+
+    def test_parse_Project_URL_single_no_version(self):
+        dist = self._makeOne('1.2')
+        dist.parse('Project-URL: Bug tracker, http://bugs.example.com/grail')
+        self.assertEqual(list(dist.project_urls),
+                         ['Bug tracker, http://bugs.example.com/grail'])
+
+    def test_parse_Project_URL_multiple(self):
+        dist = self._makeOne('1.2')
+        dist.parse('Project-URL: Bug tracker, http://bugs.example.com/grail\n'
+                   'Project-URL: Repository, http://svn.example.com/grail')
+        self.assertEqual(list(dist.project_urls),
+                         ['Bug tracker, http://bugs.example.com/grail',
+                          'Repository, http://svn.example.com/grail',
                          ])
